@@ -1,11 +1,11 @@
 # --- Common Functionality
 
-import os
 import re
 
+
 def escape_path( path ):
     # normalize slashes
-    path = re.sub( '[/\\\\]', os.sep, path )
+    path = re.sub( r'(?:/|\\\\|\\)', '/', path )
 
     # quote for spaces
     path = f'"{ path }"'
