@@ -63,6 +63,9 @@ class Runner:
         self._semaphore = None
         self._exit_task = None
 
+        self._set_asyncio_event_loop_policy()
+
+
     def register( self, hook, method ):
         """
         Registers a hook method.
@@ -470,6 +473,29 @@ class Runner:
         await self._exit_task
 
 
+    def _set_asyncio_event_loop_policy( self ):
+        """
+        Sets asyncio event loop policy.
+        
+        In some versions of Python (3.7.0 - 3.7.8) asyncio#create_subprocess_shell
+        raises a NotImplementedError on windows machines using
+        the default policy. 
+
+        This changes to a Proactor loop policy to prevent this error.
+
+        See https://stackoverflow.com/questions/53127248/asyncio-create-subprocess-shell-python-3-7-on-windows
+        for more info.
+        """
+        if platform.system() == 'Windows':
+            # change asyncio event loop policy to proactor if needed
+            try:
+                asyncio.run( asyncio.create_subprocess_shell( '' ) )
+
+            except NotImplementedError as err:
+                # change to proactor loop
+                asyncio.set_event_loop_policy( asyncio.WindowsProactorEventLoopPolicy() )
+
+
     def _register_signal_handlers( self ):
         """
         """
